# bpm-ai
_AI task automation for BPM engines._

See [bpm-ai-connectors-camunda-8](https://github.com/holunda-io/bpm-ai-connectors-camunda-8) for actual integration with the Camunda Platform 8 BPM engine using custom BPMN elements (Connectors).

## Installation
Requires Python 3.11.

```bash
$ pip install bpm-ai
```

## Development (install test dependencies)
### Linux
Install PyTorch (CPU) and spaCy:
```bash
$ pip install -r requirements.dev.txt
```

---

## License

This project is developed under

[![Apache 2.0 License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](/LICENSE)

## Sponsors and Customers

[![sponsored](https://img.shields.io/badge/sponsoredBy-Holisticon-red.svg)](https://holisticon.de/)